## 3.20.4.4 (2022-11-09)

Annotate known magic-method return types (#9131)

## 3.20.4.3 (2022-11-08)

Fix and allow classes with missing metaclasses (#9136)

## 3.20.4.2 (2022-10-25)

google.protobuf: Add an __init__ stub to fix type checking (#8982)

## 3.20.4.1 (2022-10-21)

Bump mypy-protobuf to 3.4.0 (#8951)

`types-protobuf`: Bump the rev of protobuf supported to 4.21.8 (#8937)

## 3.20.4 (2022-09-19)

Fix protobuf stubtest errors (#8758)

## 3.20.3 (2022-09-15)

protobuf: fix stubtest errors (#8735)

## 3.20.2 (2022-09-08)

[protobuf] MessageToJson indent parameter can be None (#8705)

## 3.20.1 (2022-08-26)

Bump to mypy-protobuf 3.3.0 (#8612)

* Bump to mypy-protobuf 3.3.0

* Remove some ignores for formatting

## 3.20.0 (2022-08-25)

Bump protobuf to 3.20.1 (#8609)

There are even newer versions available (4.*), but I had found a bug
in it which prevented it from working with mypy-protobuf. For now,
sticking to just 3.20.1

## 3.19.22 (2022-06-16)

`protobuf`: Delete some `__new__` and `__init__` methods (#8088)

## 3.19.21 (2022-05-21)

Simplify and correct many numeric unions (#7906)

Unblocks PyCQA/flake8-pyi#222

## 3.19.20 (2022-05-10)

Remove explicit inheritance from `object` (#7819)

## 3.19.19 (2022-05-09)

Use `str` instead of `Text` (#7812)

## 3.19.18 (2022-04-20)

Use `TypeAlias` for type aliases where possible, part II (#7667)

## 3.19.17 (2022-04-16)

Third-party stubs: import from `collections.abc` where possible (#7637)

## 3.19.16 (2022-04-16)

Use `TypeAlias` where possible for type aliases (#7630)

## 3.19.15 (2022-03-21)

Revert "Remove google/__init__.pyi (#6106)" (#7522)

This reverts commit a11a6643a7599c352ae11ac1b08dc5f3d71b106c.

## 3.19.14 (2022-03-21)

Remove google/__init__.pyi (#6106)

Since google is a namespace package, it won't have an init.
Depends on https://github.com/typeshed-internal/stub_uploader/pull/33

## 3.19.13 (2022-03-17)

Use PEP 604 syntax in non-autogenerated protobuf stubs (#7506)

## 3.19.12 (2022-02-11)

protobuf doesn't support Python 2 anymore (#7176)

Remove Python-2-only package "futures"

## 3.19.11 (2022-02-08)

protobuf: Bring back Message.Extensions (#7154)

## 3.19.10 (2022-02-07)

Improve a bunch of `__(deep)copy__` methods (#7148)

## 3.19.9 (2022-02-04)

Makes `DESCRIPTOR` non nullable again (#7125)

Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>

## 3.19.8 (2022-02-02)

Add/fix types to a bunch of non-generated protobuf files (#7017)

## 3.19.7 (2022-01-29)

Use relax_strict_optional_primitives on protobuf generated code (#7038)

Per the suggestion in https://github.com/dropbox/mypy-protobuf/issues/344
This generates more permissive constructors (which protobuf itself actually
accepts).

Philosophically, I think it makes sense for the generated code hosted on
typeshed to be most permissive, while the generated code of individual
projects can make individual decisions (defaulting to less permissive).

## 3.19.6 (2022-01-24)

Bump to mypy-protobuf 3.2.0 (#7013)

## 3.19.5 (2022-01-20)

Remove nearly all `__str__` and `__repr__` methods from typeshed (#6968)

## 3.19.4 (2022-01-19)

Use `_typeshed.Self` in `protobuf/google/protobuf/message.pyi` (#6955)

Use PEP 585 syntax in Python 2, `protobuf` & `_ast` stubs, where possible (#6949)

Flatten stubtest_allowlist for protobuf generated files (#6944)

I added stubtest testing for generated files within mypy-protobuf.
There are many ways in which the protobuf code is doing *weird*
things and we want the stubs to look a bit different. They're enumerated
in the `stubtest_allowlist.txt` of mypy-protobuf, so squashing them here
so that this one can focus on the non-generated files.

## 3.19.0 (2022-01-10)

Bump protobuf to 3.19.2 (#6879)

## 3.18.3 (2022-01-03)

Add google.protobuf.internal.api_implementation (#6802)

## 3.18.2 (2021-11-27)

Improve stubs for sequence types (#6386)

## 3.18.1 (2021-11-21)

Fix MutableMapping overrides (#6352)

## 3.18.0 (2021-10-13)

Bump protobuf stub to 3.18.1 and mypy-protobuf 3.0.0 (#6157)

* Bump protobuf stub to 3.18.1 and mypy-protobuf 3.0.0

* Fix ConsumeInteger in google/protobuf/text_format.pyi

The arg was removed in protobuf 3.18

## 3.17.5 (2021-10-12)

Add star to all non-0.1 versions (#6146)

